
#line 3 "scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 144
#define YY_END_OF_BUFFER 145
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[894] =
    {   0,
      145,  143,  144,    3,  143,  144,    1,  144,   44,  143,
      144,  143,  144,   19,  143,  144,   39,  143,  144,   41,
      143,  144,  143,  144,   28,  143,  144,   29,  143,  144,
       37,  143,  144,   35,  143,  144,   68,  143,  144,   36,
      143,  144,   34,  143,  144,   38,  143,  144,  136,  143,
      144,  136,  143,  144,   31,  143,  144,   30,  143,  144,
       46,  143,  144,   45,  143,  144,   47,  143,  144,   33,
      143,  144,   93,  133,  143,  144,   93,  133,  143,  144,
       93,  133,  143,  144,   93,  133,  143,  144,   93,  133,
      143,  144,   24,  143,  144,  143,  144,   26,  143,  144,

       40,  143,  144,   93,  133,  143,  144,   93,  133,  143,
      144,   93,  133,  143,  144,   93,  133,  143,  144,   93,
      133,  143,  144,   93,  133,  143,  144,   93,  133,  143,
      144,   93,  133,  143,  144,   93,  133,  143,  144,   93,
      133,  143,  144,   93,  133,  143,  144,   93,  133,  143,
      144,   93,  133,  143,  144,   93,  133,  143,  144,   93,
      133,  143,  144,   93,  133,  143,  144,   20,  143,  144,
       42,  143,  144,   22,  143,  144,   43,  143,  144,    3,
        1,   61,  141,   52,   23,   64,   54,  139,   50,   66,
       48,   67,   49,   69,  137,    4,    6,   51,  137,  135,

      136,  136,  136,  136,   27,   21,   25,   56,   62,   60,
       63,   57,   93,  133,   93,  133,   93,  133,   93,  133,
        2,   53,   93,  133,   93,  133,   93,  133,   93,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  133,
       93,  102,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  110,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  133,
       93,  133,   93,  133,   55,   65,   32,  137,    6,  135,
      136,  135,  136,  138,  136,  136,  136,  134,   58,   59,

       93,  133,   93,  133,  142,  140,   93,  133,   93,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  133,
       93,   94,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  108,  133,
       93,  133,   93,  133,   93,  112,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,

      133,  137,  135,  136,  135,  136,  135,  136,  138,  136,
      134,  134,   93,  133,   93,  133,   93,  133,   89,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,   95,  133,   93,  133,
       93,   97,  133,   93,   98,  133,   93,  133,   93,  133,
       93,  133,   93,  133,   93,  104,  133,   93,  105,  133,
       93,  133,   93,  133,   93,  133,   93,  109,  133,   93,
      133,   93,  117,  133,   93,  133,   93,  133,   93,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  133,

       93,  133,   91,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  130,  133,   93,  133,   93,  133,   18,   13,
      135,  136,  134,  134,  134,   90,   93,  133,   93,  133,
       93,  133,   86,   93,  133,   72,   93,  133,   93,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  133,
       93,   96,  133,   93,   99,  133,   93,  133,   93,  133,
       93,  133,   93,  133,   92,   93,  133,   93,  107,  133,
       93,  133,   93,  133,   93,  133,   93,  133,   93,  121,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,

      133,   93,  133,   93,  128,  133,   93,  133,   93,  133,
       93,  132,  133,   15,  134,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  103,  133,
       93,  106,  133,   93,  111,  133,   93,  133,   93,  133,
       93,  120,  133,   93,  122,  133,   93,  123,  133,   93,
      124,  133,   93,  125,  133,   93,  126,  133,   93,  133,
       93,  133,   93,  133,   14,   16,    5,   93,  133,   93,
      133,   73,   93,  133,   93,  133,   76,   93,  133,   93,

      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      101,  133,   93,  133,   93,  133,   93,  127,  133,   93,
      133,   93,  133,   12,   93,  133,   93,  133,   93,  133,
       93,  133,   79,   93,  133,   93,  116,  133,   93,  133,
       93,  133,   93,  133,   83,   93,  133,   93,  133,   93,
      133,   93,  100,  133,   93,  118,  133,   93,  119,  133,
       93,  129,  133,   93,  131,  133,    8,   11,   17,   93,
      133,   93,  133,   93,  133,   93,  133,   93,  133,   93,
      133,   80,   93,  133,   93,  133,   93,  133,   93,  115,

      133,   93,  133,    7,    8,   93,  133,   93,  133,   93,
      133,   93,  133,   78,   93,  133,   93,  114,  133,   82,
       93,  133,   81,   93,  133,   93,  133,   84,   93,  133,
       93,  133,   93,  133,   75,   93,  133,   93,  133,   93,
      113,  133,   93,  133,   93,  133,   93,  133,   93,  133,
       93,  133,   85,   93,  133,   93,  133,   93,  133,   74,
       93,  133,   77,   93,  133,   93,  133,   93,  133,   70,
       93,  133,   93,  133,   93,  133,   93,  133,   71,   87,
       93,  133,   93,  133,   88,   93,  133,    9,    9,   12,
       10,   10,   11

    } ;

static yyconst flex_int16_t yy_accept[577] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   85,   89,   93,   96,   98,  101,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  160,  164,  168,  171,  174,  177,  180,  181,  182,
      183,  183,  184,  184,  184,  184,  184,  184,  184,  185,
      186,  187,  188,  188,  189,  189,  190,  191,  192,  193,
      194,  195,  195,  196,  197,  198,  199,  200,  202,  203,
      203,  204,  205,  205,  206,  207,  208,  209,  210,  211,

      212,  213,  215,  217,  219,  219,  219,  221,  222,  223,
      225,  227,  229,  231,  233,  235,  237,  239,  241,  244,
      246,  248,  250,  252,  254,  256,  258,  261,  263,  265,
      267,  269,  271,  273,  275,  277,  279,  281,  283,  285,
      286,  287,  287,  287,  287,  287,  287,  287,  288,  288,
      289,  289,  289,  290,  292,  294,  294,  295,  296,  297,
      298,  299,  300,  301,  303,  305,  305,  306,  306,  306,
      307,  307,  309,  311,  313,  315,  317,  319,  321,  323,
      325,  327,  329,  331,  334,  336,  338,  340,  342,  344,
      346,  348,  350,  352,  354,  356,  358,  361,  363,  365,

      368,  370,  372,  374,  376,  378,  380,  382,  384,  386,
      388,  390,  392,  394,  396,  398,  400,  402,  402,  402,
      402,  402,  402,  402,  402,  402,  402,  402,  403,  403,
      405,  407,  409,  410,  411,  412,  413,  415,  417,  419,
      422,  424,  426,  428,  430,  432,  434,  436,  438,  440,
      442,  444,  446,  449,  451,  454,  457,  459,  461,  463,
      465,  468,  471,  473,  475,  477,  480,  482,  485,  487,
      489,  491,  493,  495,  497,  499,  501,  503,  506,  508,
      510,  512,  515,  517,  519,  519,  520,  520,  520,  520,
      520,  520,  521,  521,  521,  521,  521,  523,  524,  525,

      526,  529,  531,  533,  536,  539,  541,  543,  545,  547,
      549,  551,  553,  555,  557,  559,  561,  564,  567,  569,
      571,  573,  575,  578,  581,  583,  585,  587,  589,  592,
      594,  596,  598,  600,  602,  604,  607,  609,  611,  614,
      614,  614,  614,  615,  615,  615,  615,  615,  615,  615,
      616,  618,  620,  620,  622,  624,  626,  628,  630,  632,
      634,  636,  638,  640,  642,  644,  646,  648,  651,  654,
      657,  659,  661,  664,  667,  670,  673,  676,  679,  681,
      683,  685,  685,  685,  686,  686,  687,  687,  687,  687,
      687,  688,  690,  692,  692,  695,  697,  700,  702,  704,

      706,  708,  710,  712,  714,  716,  718,  720,  723,  725,
      727,  730,  732,  734,  734,  734,  734,  734,  735,  735,
      735,  735,  735,  737,  739,  739,  739,  741,  743,  746,
      749,  751,  753,  755,  758,  760,  762,  765,  768,  771,
      774,  777,  778,  778,  778,  778,  778,  778,  779,  779,
      779,  780,  782,  784,  784,  784,  786,  788,  790,  792,
      795,  797,  799,  802,  804,  805,  806,  806,  806,  806,
      806,  808,  810,  810,  810,  812,  814,  817,  820,  823,
      826,  828,  831,  831,  831,  831,  831,  833,  835,  835,
      835,  838,  840,  843,  845,  845,  845,  845,  845,  847,

      849,  849,  849,  851,  853,  856,  856,  856,  856,  856,
      858,  860,  860,  860,  863,  866,  866,  866,  866,  866,
      868,  870,  871,  871,  871,  871,  871,  871,  873,  875,
      875,  875,  875,  875,  875,  877,  879,  880,  880,  880,
      880,  880,  883,  885,  885,  885,  885,  885,  888,  888,
      888,  888,  888,  888,  888,  888,  888,  888,  888,  888,
      888,  888,  888,  889,  889,  889,  891,  891,  891,  891,
      891,  892,  892,  892,  894,  894
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   23,   25,   23,   26,   27,   28,   29,   30,
       31,   32,   33,    1,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   41,   41,   43,   41,   44,   45,   41,
       41,   46,   47,   48,   49,   41,   41,   50,   41,   41,
       51,   52,   53,   54,   55,    1,   56,   57,   58,   59,

       60,   61,   62,   63,   64,   41,   65,   66,   67,   68,
       69,   70,   41,   71,   72,   73,   74,   75,   76,   77,
       78,   79,   80,   81,   82,   83,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[84] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    2,    1,    1,    1,    5,
        5,    5,    5,    5,    5,    5,    5,    1,    1,    1,
        2,    1,    1,    6,    6,    6,    6,    6,    6,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        1,    1,    1,    1,    7,    6,    6,    6,    6,    6,
        6,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    1,
        1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[599] =
    {   0,
        0,    0,  947,  948,   82,    0,  915,   78,   83,   58,
       81,   81,  948,  948,  914,   78,  948,   79,   77,   94,
      136,  196,  912,  948,   96,  912,   75,  948,    0,  908,
      886,  107,  894,  948,  936,  948,  907,   80,   45,  866,
       60,   62,   68,   72,  867,   71,  866,  874,  102,   66,
      865,  863,  868,  948,   89,  948,  948,  144,    0,  948,
      143,  948,  927,  167,  869,  101,  867,  856,  948,  948,
      948,  948,  129,  948,  923,  948,  948,  948,  948,  948,
      948,  907,  251,  150,    0,  948,    0,  134,    0,  226,
      133,  158,    0,  948,  948,  948,  893,  948,  948,  948,

      892,    0,  879,  881,  157,  160,  871,  948,  948,  850,
      224,  851,  844,  856,  843,  858,  845,  851,  837,  838,
      835,  835,  841,  837,  834,  831,    0,  131,  835,  153,
      833,   89,  171,  837,  826,  829,  134,  139,  834,  948,
      948,  280,  836,  164,  837,  250,  839,  948,  299,  948,
      864,    0,    0,  195,  188,  307,  315,  183,  948,  192,
      217,  948,  948,  846,  188,  256,  948,  889,  229,  948,
      888,  852,  820,  100,  819,  810,  818,  816,  824,  819,
      804,  817,  811,    0,  810,  822,  817,  805,  192,  819,
      817,  813,  805,  811,  798,  813,    0,  799,  803,    0,

      804,  801,  791,  789,  791,  793,  800,  786,  784,  784,
      796,  795,  785,  789,  793,  795,  784,  846,  784,  786,
      786,  781,  841,  783,  783,  779,  323,  339,  808,  219,
      948,  244,  948,  948,  324,  308,  801,  794,  795,    0,
      770,  768,  761,  765,  759,  213,  763,  758,  767,  758,
      759,  760,    0,  760,    0,    0,  751,  759,  748,  755,
        0,    0,  749,  759,  745,    0,  749,    0,  744,  744,
      743,  740,  752,  742,  746,  751,  750,    0,  748,  738,
      743,    0,  731,  743,  799,  948,  733,  795,  796,  737,
      794,  948,  735,  735,  727,  366,  948,  303,  948,  313,

        0,  745,  748,    0,  381,  720,  718,  729,  724,  766,
      718,  712,  716,  723,  709,  725,    0,    0,  712,  713,
      718,  709,    0,    0,  716,  702,  710,  705,    0,  713,
      710,  712,  696,  705,  707,    0,  698,  701,    0,  704,
      760,  759,  948,  758,  367,  699,  703,  744,  738,  948,
      731,  707,  387,  699,  689,  679,  683,  682,  727,  674,
      676,  686,  676,  723,  670,  668,  668,    0,    0,    0,
      680,  681,    0,    0,    0,    0,    0,    0,  677,  677,
      670,  730,  731,  948,  730,  948,  382,  391,  397,  727,
      948,  707,  705,  660,  399,  671,    0,  655,  666,  699,

      658,  659,  663,  660,  698,  655,  658,    0,  646,  643,
        0,  656,  654,    0,  658,  709,  404,  948,  367,  406,
      410,  708,  655,  685,  642,  412,  633,  642,  650,  649,
      637,  644,  646,    0,  674,  633,    0,    0,    0,    0,
        0,  686,  657,  385,  641,  692,  416,  948,  372,  691,
      948,  657,  637,  635,  621,  616,  619,  632,  613,    0,
      612,  629,  628,  622,  948,  669,  638,  392,  639,  407,
      633,  641,  603,  609,  614,  605,    0,    0,    0,    0,
      599,  616,  615,  394,  627,  421,  624,  622,  602,  609,
      609,  608,    0,  607,  614,  310,  605,  417,  612,  614,

      591,  583,  600,  599,    0,  617,  420,  605,  423,  603,
      603,  589,  584,    0,    0,  613,  426,  610,  428,  611,
      596,  948,  484,  505,  425,  493,  432,  459,  465,  438,
      451,  429,  449,  430,  444,  446,  948,  447,  437,  440,
      435,    0,  435,  435,  436,  430,  438,    0,  412,  439,
      412,  440,  397,  441,  375,  442,  448,  452,  300,  445,
      350,  312,  948,  264,  256,  948,  475,  486,  230,  226,
      948,  118,   91,  948,  948,  500,  507,  514,  517,  524,
      527,  533,  540,  546,  553,  560,  567,  574,  581,  588,
      590,  597,  604,  608,  615,  622,  629,  636

    } ;

static yyconst flex_int16_t yy_def[599] =
    {   0,
      575,    1,  575,  575,  575,  576,  575,  577,  575,  575,
      575,  578,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  579,  579,
      579,  579,  579,  575,  575,  575,  575,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  575,  575,  575,  575,  575,  576,  575,
      577,  575,  577,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  578,  575,  578,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  580,  575,   83,   21,   22,  575,
      575,  575,  581,  575,  575,  575,  575,  575,  575,  575,

      575,  579,  579,  579,  582,  583,  579,  575,  575,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  584,  580,  575,  575,  575,  575,  575,  575,  575,
      581,  575,  575,  579,  579,  582,  575,  582,  583,  575,
      583,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,

      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  585,  575,  575,
      575,  575,  586,  575,  575,  575,  575,  575,  584,  575,
      575,  575,  575,  575,  575,  575,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  585,  575,  575,  575,  587,  575,
      586,  575,  575,  575,  575,  575,  575,  575,  575,  575,

      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  575,
      588,  587,  575,  589,  575,  575,  575,  575,  575,  575,
      579,  579,  575,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  575,  588,  575,  589,  575,  575,  590,  575,  575,
      575,  579,  579,  575,  579,  579,  579,  579,  579,  579,

      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  591,  575,  590,  590,  575,  590,  575,
      592,  593,  579,  579,  575,  575,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  594,  575,  590,  575,  592,  592,  575,  592,  593,
      575,  579,  579,  575,  575,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  575,  594,  575,  590,  575,  592,
      579,  579,  575,  575,  579,  579,  579,  579,  579,  579,
      579,  579,  575,  590,  575,  592,  579,  579,  575,  575,
      579,  579,  579,  579,  575,  590,  575,  592,  579,  579,

      575,  575,  579,  579,  579,  575,  590,  575,  592,  579,
      579,  575,  575,  579,  579,  575,  590,  575,  592,  579,
      579,  575,  575,  575,  590,  575,  592,  579,  579,  575,
      575,  590,  575,  592,  579,  579,  575,  575,  590,  575,
      592,  579,  579,  575,  590,  575,  592,  579,  575,  590,
      575,  592,  575,  590,  575,  592,  595,  596,  575,  592,
      595,  595,  575,  596,  596,  575,  597,  598,  597,  597,
      575,  598,  598,  575,    0,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575

    } ;

static yyconst flex_int16_t yy_nxt[1032] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   23,   24,   25,
       26,   27,   28,   29,   29,   29,   29,   29,   30,   31,
       29,   29,   32,   29,   29,   29,   29,   33,   29,   29,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   45,   29,   46,   29,   47,   29,   29,   29,   29,
       48,   49,   50,   51,   52,   53,   29,   29,   29,   54,
       55,   56,   57,   58,   62,   58,   58,   64,   69,   70,
       71,   74,   77,  574,   82,   79,   83,   83,   83,   83,

       83,   83,   83,   83,   95,  100,  101,   84,   78,   80,
       81,   72,   85,  105,  110,  115,  112,  106,  113,  140,
      574,  118,  116,   96,   86,   97,   98,  123,  117,   63,
      119,  127,   75,  120,  111,  121,  135,  124,  128,   74,
      125,   65,   66,  136,  122,   58,   67,   58,   58,   62,
      206,  151,   68,   87,  151,   88,   88,   88,   88,   88,
       88,   89,   89,  167,  131,  132,  144,  207,  145,  141,
      170,  242,  243,   90,  133,  158,  154,  134,   91,  152,
       75,  159,  155,  575,   92,   93,  142,  142,  142,  142,
      142,  142,  142,  142,   63,   90,  199,  213,  158,  154,

      160,   91,  215,  200,  216,  214,  159,  155,  168,   92,
      575,  171,   93,   87,  202,   89,   89,   89,   89,   89,
       89,   89,   89,  160,  203,  204,  208,  220,  571,  238,
      232,  159,  571,   90,  234,  221,  239,  230,   91,  170,
      156,  209,  156,  231,   92,  157,  157,  157,  157,  157,
      157,  157,  157,  232,  223,   90,  159,  234,  566,  235,
      230,   91,  167,  257,  258,  236,  566,  231,  231,   92,
       83,   83,   83,   83,   83,   83,   83,   83,  309,  174,
      171,  175,  235,  176,  218,  310,  297,  177,  149,  150,
      236,  178,  231,  150,  179,  180,  181,  182,  183,  142,

      142,  142,  142,  142,  142,  142,  142,  168,  224,  297,
      149,  150,  418,  227,  563,  227,  150,  225,  228,  228,
      228,  228,  228,  228,  228,  228,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  157,  228,  228,  228,  228,  228,  228,  228,  228,
      300,  299,  563,  233,  567,  350,  507,  233,  228,  228,
      228,  228,  228,  228,  228,  228,  298,  348,  387,  418,
      348,  388,  299,  300,  448,  233,  299,  150,  350,  349,
      233,  150,  353,  387,  353,  353,  387,  418,  353,  298,
      353,  353,  417,  418,  418,  417,  418,  299,  420,  150,

      426,  421,  426,  426,  150,  417,  418,  420,  417,  448,
      420,  447,  448,  426,  447,  426,  426,  447,  448,  448,
      447,  444,  418,  448,  468,  448,  470,  418,  418,  559,
      448,  418,  448,  484,  448,  354,  415,  448,  418,  418,
      448,  418,  448,  418,  448,  419,  486,  448,  496,  562,
      563,  557,  562,  565,  566,  517,  565,  555,  419,  525,
      445,  394,  498,  527,  449,  534,  553,  551,  532,  519,
      449,  509,  539,  541,  545,  552,  570,  571,  547,  570,
      549,  550,  548,  546,  544,  556,  455,  573,  574,  543,
      573,  542,  540,  554,  538,  558,  560,  537,  536,  568,

       59,   59,  535,   59,   59,   59,   59,   61,   61,   61,
       61,   61,   61,   61,   73,   73,   73,   73,   73,   73,
       73,  102,  102,  102,  153,  153,  533,  153,  153,  153,
      153,  161,  161,  166,  166,  166,  166,  166,  166,  166,
      169,  169,  169,  169,  169,  169,  169,  229,  531,  530,
      229,  229,  229,  285,  285,  285,  285,  285,  285,  285,
      291,  291,  291,  291,  291,  291,  291,  342,  342,  342,
      342,  342,  342,  342,  383,  383,  383,  383,  383,  383,
      383,  385,  385,  385,  385,  385,  385,  385,  416,  416,
      416,  416,  416,  416,  416,  442,  442,  446,  446,  446,

      446,  446,  446,  446,  450,  450,  450,  450,  450,  450,
      450,  466,  466,  466,  466,  561,  561,  561,  561,  561,
      561,  561,  564,  564,  564,  564,  564,  564,  564,  569,
      569,  569,  569,  569,  569,  569,  572,  572,  572,  572,
      572,  572,  572,  529,  528,  526,  524,  523,  522,  521,
      520,  518,  516,  515,  514,  513,  512,  511,  510,  508,
      506,  505,  504,  503,  502,  501,  500,  499,  497,  495,
      494,  493,  492,  491,  490,  489,  488,  487,  485,  483,
      465,  482,  481,  480,  479,  478,  477,  476,  475,  474,
      473,  472,  471,  451,  448,  469,  467,  465,  464,  463,

      462,  461,  460,  459,  458,  457,  456,  454,  453,  452,
      451,  418,  443,  441,  440,  439,  438,  437,  436,  435,
      434,  433,  432,  431,  430,  429,  428,  427,  425,  424,
      423,  422,  386,  384,  414,  413,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  403,  402,  401,  400,  399,
      398,  397,  396,  395,  393,  392,  391,  349,  390,  389,
      386,  343,  384,  382,  381,  380,  379,  378,  377,  376,
      375,  374,  373,  372,  371,  370,  369,  368,  367,  366,
      365,  364,  363,  362,  361,  360,  359,  358,  357,  356,
      355,  352,  351,  347,  346,  345,  292,  344,  343,  341,

      340,  286,  339,  338,  337,  336,  335,  334,  333,  332,
      331,  330,  329,  328,  327,  326,  325,  324,  323,  322,
      321,  320,  319,  318,  317,  316,  315,  314,  313,  312,
      311,  308,  307,  306,  305,  304,  303,  302,  301,  296,
      295,  294,  293,  292,  290,  289,  288,  287,  286,  284,
      283,  282,  281,  280,  279,  278,  277,  276,  275,  274,
      273,  272,  271,  270,  269,  268,  267,  266,  265,  264,
      263,  262,  261,  260,  259,  256,  255,  254,  253,  252,
      251,  250,  249,  248,  247,  246,  245,  244,  241,  240,
      575,  575,  237,  152,  226,  222,  219,  217,  212,  211,

      210,  205,  201,  198,  197,  196,  195,  194,  193,  192,
      191,  190,  189,  188,  187,  186,  185,  184,  173,  172,
      165,  164,  163,  162,  148,  575,  147,  146,  143,  575,
      139,  138,  137,  130,  129,  126,  114,  109,  108,  107,
      104,  103,   99,   94,   76,   60,  575,    3,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,

      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575
    } ;

static yyconst flex_int16_t yy_chk[1032] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    5,    8,    5,    5,    9,   10,   10,
       11,   12,   16,  573,   19,   18,   19,   19,   19,   19,

       19,   19,   19,   19,   25,   27,   27,   20,   16,   18,
       18,   11,   20,   32,   38,   41,   39,   32,   39,   55,
      572,   42,   41,   25,   20,   25,   25,   44,   41,    8,
       42,   46,   12,   43,   38,   43,   50,   44,   46,   73,
       44,    9,    9,   50,   43,   58,    9,   58,   58,   61,
      132,   84,    9,   21,   84,   21,   21,   21,   21,   21,
       21,   21,   21,  105,   49,   49,   66,  132,   66,   55,
      106,  174,  174,   21,   49,   91,   88,   49,   21,   84,
       73,   91,   88,   88,   21,   21,   64,   64,   64,   64,
       64,   64,   64,   64,   61,   21,  128,  137,   91,   88,

       92,   21,  138,  128,  138,  137,   91,   88,  105,   21,
       88,  106,   21,   22,  130,   22,   22,   22,   22,   22,
       22,   22,   22,   92,  130,  130,  133,  144,  570,  165,
      155,  158,  569,   22,  160,  144,  165,  154,   22,  169,
       90,  133,   90,  154,   22,   90,   90,   90,   90,   90,
       90,   90,   90,  155,  146,   22,  158,  160,  565,  161,
      154,   22,  166,  189,  189,  161,  564,  230,  154,   22,
       83,   83,   83,   83,   83,   83,   83,   83,  246,  111,
      169,  111,  161,  111,  142,  246,  232,  111,   83,   83,
      161,  111,  230,   83,  111,  111,  111,  111,  111,  142,

      142,  142,  142,  142,  142,  142,  142,  166,  146,  232,
       83,   83,  496,  149,  562,  149,   83,  146,  149,  149,
      149,  149,  149,  149,  149,  149,  156,  156,  156,  156,
      156,  156,  156,  156,  157,  157,  157,  157,  157,  157,
      157,  157,  227,  227,  227,  227,  227,  227,  227,  227,
      236,  298,  561,  157,  559,  300,  496,  157,  228,  228,
      228,  228,  228,  228,  228,  228,  235,  296,  345,  419,
      296,  345,  235,  236,  449,  157,  298,  228,  300,  296,
      157,  228,  305,  387,  305,  305,  387,  444,  353,  235,
      353,  353,  388,  388,  468,  388,  484,  235,  389,  228,

      395,  389,  395,  395,  228,  417,  417,  420,  417,  470,
      420,  421,  421,  426,  421,  426,  426,  447,  447,  498,
      447,  419,  507,  486,  444,  509,  449,  525,  517,  555,
      519,  532,  534,  468,  527,  305,  387,  541,  545,  539,
      547,  550,  552,  554,  556,  388,  470,  560,  484,  557,
      557,  553,  557,  558,  558,  507,  558,  551,  417,  517,
      420,  353,  486,  519,  421,  527,  549,  546,  525,  509,
      447,  498,  532,  534,  539,  547,  567,  567,  541,  567,
      544,  545,  543,  540,  538,  552,  426,  568,  568,  536,
      568,  535,  533,  550,  531,  554,  556,  530,  529,  560,

      576,  576,  528,  576,  576,  576,  576,  577,  577,  577,
      577,  577,  577,  577,  578,  578,  578,  578,  578,  578,
      578,  579,  579,  579,  580,  580,  526,  580,  580,  580,
      580,  581,  581,  582,  582,  582,  582,  582,  582,  582,
      583,  583,  583,  583,  583,  583,  583,  584,  524,  523,
      584,  584,  584,  585,  585,  585,  585,  585,  585,  585,
      586,  586,  586,  586,  586,  586,  586,  587,  587,  587,
      587,  587,  587,  587,  588,  588,  588,  588,  588,  588,
      588,  589,  589,  589,  589,  589,  589,  589,  590,  590,
      590,  590,  590,  590,  590,  591,  591,  592,  592,  592,

      592,  592,  592,  592,  593,  593,  593,  593,  593,  593,
      593,  594,  594,  594,  594,  595,  595,  595,  595,  595,
      595,  595,  596,  596,  596,  596,  596,  596,  596,  597,
      597,  597,  597,  597,  597,  597,  598,  598,  598,  598,
      598,  598,  598,  521,  520,  518,  516,  513,  512,  511,
      510,  508,  506,  504,  503,  502,  501,  500,  499,  497,
      495,  494,  492,  491,  490,  489,  488,  487,  485,  483,
      482,  481,  476,  475,  474,  473,  472,  471,  469,  467,
      466,  464,  463,  462,  461,  459,  458,  457,  456,  455,
      454,  453,  452,  450,  446,  445,  443,  442,  436,  435,

      433,  432,  431,  430,  429,  428,  427,  425,  424,  423,
      422,  416,  415,  413,  412,  410,  409,  407,  406,  405,
      404,  403,  402,  401,  400,  399,  398,  396,  394,  393,
      392,  390,  385,  383,  382,  381,  380,  379,  372,  371,
      367,  366,  365,  364,  363,  362,  361,  360,  359,  358,
      357,  356,  355,  354,  352,  351,  349,  348,  347,  346,
      344,  342,  341,  340,  338,  337,  335,  334,  333,  332,
      331,  330,  328,  327,  326,  325,  322,  321,  320,  319,
      316,  315,  314,  313,  312,  311,  310,  309,  308,  307,
      306,  303,  302,  295,  294,  293,  291,  290,  289,  288,

      287,  285,  284,  283,  281,  280,  279,  277,  276,  275,
      274,  273,  272,  271,  270,  269,  267,  265,  264,  263,
      260,  259,  258,  257,  254,  252,  251,  250,  249,  248,
      247,  245,  244,  243,  242,  241,  239,  238,  237,  229,
      226,  225,  224,  223,  222,  221,  220,  219,  218,  217,
      216,  215,  214,  213,  212,  211,  210,  209,  208,  207,
      206,  205,  204,  203,  202,  201,  199,  198,  196,  195,
      194,  193,  192,  191,  190,  188,  187,  186,  185,  183,
      182,  181,  180,  179,  178,  177,  176,  175,  173,  172,
      171,  168,  164,  151,  147,  145,  143,  139,  136,  135,

      134,  131,  129,  126,  125,  124,  123,  122,  121,  120,
      119,  118,  117,  116,  115,  114,  113,  112,  110,  107,
      104,  103,  101,   97,   82,   75,   68,   67,   65,   63,
       53,   52,   51,   48,   47,   45,   40,   37,   35,   33,
       31,   30,   26,   23,   15,    7,    3,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,

      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "giscanner/scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "giscanner/scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#ifndef _WIN32
#include <limits.h>
#endif

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"

#ifdef USE_WINDOWS
#include <windows.h>
#endif

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
static void print_error (GISourceScanner *scanner);
#line 1042 "scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 72 "giscanner/scannerlexer.l"


#line 1225 "scannerlexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 576 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 948 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 74 "giscanner/scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 80 "giscanner/scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 82 "giscanner/scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 84 "giscanner/scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 85 "giscanner/scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 86 "giscanner/scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 88 "giscanner/scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 89 "giscanner/scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 90 "giscanner/scannerlexer.l"
{ return IFDEF_GI_SCANNER; }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 91 "giscanner/scannerlexer.l"
{ return IFNDEF_GI_SCANNER; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 92 "giscanner/scannerlexer.l"
{ return IFNDEF_COND; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 93 "giscanner/scannerlexer.l"
{ return IFDEF_COND; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 94 "giscanner/scannerlexer.l"
{ return IF_COND; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 95 "giscanner/scannerlexer.l"
{ return ELIF_COND; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 96 "giscanner/scannerlexer.l"
{ return ELSE_COND; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 97 "giscanner/scannerlexer.l"
{ return ENDIF_COND; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 98 "giscanner/scannerlexer.l"
{ /* Ignore pragma. */ }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 100 "giscanner/scannerlexer.l"
{ process_linemarks(scanner); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 101 "giscanner/scannerlexer.l"
{ }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 102 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 103 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 104 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 105 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 106 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 107 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 108 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 109 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 110 "giscanner/scannerlexer.l"
{ return '('; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 111 "giscanner/scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 112 "giscanner/scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 113 "giscanner/scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 114 "giscanner/scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 115 "giscanner/scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 116 "giscanner/scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 117 "giscanner/scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 118 "giscanner/scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 119 "giscanner/scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 120 "giscanner/scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 121 "giscanner/scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 122 "giscanner/scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 123 "giscanner/scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 124 "giscanner/scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 125 "giscanner/scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 126 "giscanner/scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 127 "giscanner/scannerlexer.l"
{ return '='; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 128 "giscanner/scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 129 "giscanner/scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 130 "giscanner/scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 131 "giscanner/scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 132 "giscanner/scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 133 "giscanner/scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 134 "giscanner/scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 135 "giscanner/scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 136 "giscanner/scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 137 "giscanner/scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 138 "giscanner/scannerlexer.l"
{ return SL; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 139 "giscanner/scannerlexer.l"
{ return SR; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 140 "giscanner/scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 141 "giscanner/scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 142 "giscanner/scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 143 "giscanner/scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 144 "giscanner/scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 145 "giscanner/scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 146 "giscanner/scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 147 "giscanner/scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 148 "giscanner/scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 149 "giscanner/scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 150 "giscanner/scannerlexer.l"
{ return ','; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 151 "giscanner/scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 153 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 154 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 155 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 156 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 157 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 158 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 159 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 160 "giscanner/scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 161 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 162 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 163 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 164 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 165 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 166 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 167 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 168 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 169 "giscanner/scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 171 "giscanner/scannerlexer.l"
{ return INTL_CONST; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 172 "giscanner/scannerlexer.l"
{ return INTUL_CONST; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 174 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 175 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 176 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 177 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 179 "giscanner/scannerlexer.l"
{ if (scanner->macro_scan) return check_identifier(scanner, yytext); else REJECT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 181 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 182 "giscanner/scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 183 "giscanner/scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 184 "giscanner/scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 185 "giscanner/scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 186 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 187 "giscanner/scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 188 "giscanner/scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 189 "giscanner/scannerlexer.l"
{ return DO; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 190 "giscanner/scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 191 "giscanner/scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 192 "giscanner/scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 193 "giscanner/scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 194 "giscanner/scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 195 "giscanner/scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 196 "giscanner/scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 197 "giscanner/scannerlexer.l"
{ return IF; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 198 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 199 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 200 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 201 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 202 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 203 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 204 "giscanner/scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 205 "giscanner/scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 206 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 207 "giscanner/scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 208 "giscanner/scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 209 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 210 "giscanner/scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 211 "giscanner/scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 212 "giscanner/scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 213 "giscanner/scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 214 "giscanner/scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 215 "giscanner/scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 216 "giscanner/scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 217 "giscanner/scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 218 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 219 "giscanner/scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 221 "giscanner/scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 223 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 224 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 225 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 227 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 228 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 139:
/* rule 139 can match eol */
YY_RULE_SETUP
#line 230 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 140:
/* rule 140 can match eol */
YY_RULE_SETUP
#line 231 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 141:
/* rule 141 can match eol */
YY_RULE_SETUP
#line 233 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 142:
/* rule 142 can match eol */
YY_RULE_SETUP
#line 234 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 236 "giscanner/scannerlexer.l"
{ print_error(scanner); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 238 "giscanner/scannerlexer.l"
ECHO;
	YY_BREAK
#line 2058 "scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 576 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 576 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 575);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 238 "giscanner/scannerlexer.l"



static int
yywrap (void)
{
  return 1;
}

static void
parse_comment (GISourceScanner *scanner)
{
  int c1, c2;
  GString *string = NULL;
  GISourceComment *comment;
  int comment_lineno;
  int skip = FALSE;

  c1 = input();
  c2 = input();

  if (c2 != EOF && (c1 == '*' && c2 != '*' && c2 != '/')) {
    /*
     * Store GTK-Doc comment blocks,
     * starts with one '/' followed by exactly two '*' and not followed by a '/'
     */
    if (!g_hash_table_contains (scanner->files, scanner->current_file)) {
        skip = TRUE;
    } else {
        string = g_string_new (yytext);
    }

    comment_lineno = lineno;

    while (c2 != EOF && !(c1 == '*' && c2 == '/'))
      {
        if (!skip)
          g_string_append_c (string, c1);

        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    if (skip) {
        return;
    }

    g_string_append (string, "*/");

    comment = g_slice_new (GISourceComment);
    comment->comment = g_string_free (string, FALSE);
    comment->line = comment_lineno;
    comment->filename = g_file_get_parse_name (scanner->current_file);

    gi_source_scanner_take_comment (scanner, comment);
  } else {
    /*
     * Ignore all other comment blocks
     */
    while (c2 != EOF && !(c1 == '*' && c2 == '/'))
      {
        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    return;
  }
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/* taken from glib/gfileutils.c */
#if defined(MAXPATHLEN)
#define G_PATH_LENGTH MAXPATHLEN
#elif defined(PATH_MAX)
#define G_PATH_LENGTH PATH_MAX
#elif defined(_PC_PATH_MAX)
#define G_PATH_LENGTH sysconf(_PC_PATH_MAX)
#else
#define G_PATH_LENGTH 2048
#endif

static inline char *
_realpath (const char *path)
{
#ifndef _WIN32
  char buffer[G_PATH_LENGTH];

  return realpath (path, buffer) ? g_strdup (buffer) : NULL;
#else
  /* We don't want to include <windows.h> as it clashes horribly
   * with token names from scannerparser.h. So just declare
   * GetFullPathNameA() here unless we already defined it, like
   * in giscanner.c.
   */
#ifndef USE_WINDOWS
  extern __stdcall GetFullPathNameA(const char*, int, char*, char**);
#endif
  char *buffer;
  char dummy;
  int rc, len;

  rc = GetFullPathNameA (path, 1, &dummy, NULL);
  if (rc == 0)
    {
      /* Weird failure, so just return the input path as such */
      return g_strdup (path);
    }

  len = rc + 1;
  buffer = g_malloc (len);

  rc = GetFullPathNameA (path, len, buffer, NULL);
  if (rc == 0 || rc > len)
    {
      /* Weird failure again */
      g_free (buffer);
      return g_strdup (path);
    }
  return buffer;
#endif
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner)
{
	char escaped_filename[1025];
	char *filename;
        char *real;

	sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);
	filename = g_strcompress (escaped_filename);

        real = _realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (scanner->current_file)
          g_object_unref (scanner->current_file);
	scanner->current_file = g_file_new_for_path (filename);
	g_free (filename);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

static void
print_error (GISourceScanner *scanner)
{
  if (yytext[0]) {
    char *filename = g_file_get_parse_name (scanner->current_file);
    fprintf(stderr, "%s:%d: unexpected character `%c'\n", filename, lineno, yytext[0]);
    g_free (filename);
  }
}

